@@ -229,12 +229,12 @@ class User(Snowflake, Protocol):
 
     @property
     def display_name(self) -> str:
-        """:class:`str`: Returns the user's display name."""
+        """Returns the user's display name."""
         raise NotImplementedError
 
     @property
     def mention(self) -> str:
-        """:class:`str`: Returns a string that allows you to mention the given user."""
+        """Returns a string that allows you to mention the given user."""
         raise NotImplementedError
 
 
@@ -400,6 +400,26 @@ class GuildChannel:
         except KeyError:
             pass
 
+        try:
+            options["default_thread_rate_limit_per_user"] = options.pop(
+                "default_thread_slowmode_delay"
+            )
+        except KeyError:
+            pass
+
+        try:
+            if options.pop("require_tag"):
+                options["flags"] = ChannelFlags.require_tag.flag
+        except KeyError:
+            pass
+
+        try:
+            options["available_tags"] = [
+                tag.to_dict() for tag in options.pop("available_tags")
+            ]
+        except KeyError:
+            pass
+
         try:
             rtc_region = options.pop("rtc_region")
         except KeyError:
@@ -449,7 +469,8 @@ class GuildChannel:
             for target, perm in overwrites.items():
                 if not isinstance(perm, PermissionOverwrite):
                     raise InvalidArgument(
-                        f"Expected PermissionOverwrite received {perm.__class__.__name__}"
+                        "Expected PermissionOverwrite received"
+                        f" {perm.__class__.__name__}"
                     )
 
                 allow, deny = perm.pair()
@@ -457,9 +478,11 @@ class GuildChannel:
                     "allow": allow.value,
                     "deny": deny.value,
                     "id": target.id,
-                    "type": _Overwrites.ROLE
-                    if isinstance(target, Role)
-                    else _Overwrites.MEMBER,
+                    "type": (
+                        _Overwrites.ROLE
+                        if isinstance(target, Role)
+                        else _Overwrites.MEMBER
+                    ),
                 }
 
                 perms.append(payload)
@@ -506,7 +529,7 @@ class GuildChannel:
 
     @property
     def changed_roles(self) -> list[Role]:
-        """List[:class:`~discord.Role`]: Returns a list of roles that have been overridden from
+        """Returns a list of roles that have been overridden from
         their default values in the :attr:`~discord.Guild.roles` attribute.
         """
         ret = []
@@ -523,12 +546,12 @@ class GuildChannel:
 
     @property
     def mention(self) -> str:
-        """:class:`str`: The string that allows you to mention the channel."""
+        """The string that allows you to mention the channel."""
         return f"<#{self.id}>"
 
     @property
     def jump_url(self) -> str:
-        """:class:`str`: Returns a URL that allows the client to jump to the channel.
+        """Returns a URL that allows the client to jump to the channel.
 
         .. versionadded:: 2.0
         """
@@ -536,7 +559,7 @@ class GuildChannel:
 
     @property
     def created_at(self) -> datetime:
-        """:class:`datetime.datetime`: Returns the channel's creation time in UTC."""
+        """Returns the channel's creation time in UTC."""
         return utils.snowflake_time(self.id)
 
     def overwrites_for(self, obj: Role | User) -> PermissionOverwrite:
@@ -605,7 +628,7 @@ class GuildChannel:
 
     @property
     def category(self) -> CategoryChannel | None:
-        """Optional[:class:`~discord.CategoryChannel`]: The category this channel belongs to.
+        """The category this channel belongs to.
 
         If there is no category then this is ``None``.
         """
@@ -613,7 +636,7 @@ class GuildChannel:
 
     @property
     def permissions_synced(self) -> bool:
-        """:class:`bool`: Whether the permissions for this channel are synced with the
+        """Whether the permissions for this channel are synced with the
         category it belongs to.
 
         If there is no category then this is ``False``.
@@ -1300,6 +1323,7 @@ class Messageable:
         mention_author: bool = ...,
         view: View = ...,
         suppress: bool = ...,
+        silent: bool = ...,
     ) -> Message:
         ...
 
@@ -1319,6 +1343,7 @@ class Messageable:
         mention_author: bool = ...,
         view: View = ...,
         suppress: bool = ...,
+        silent: bool = ...,
     ) -> Message:
         ...
 
@@ -1338,6 +1363,7 @@ class Messageable:
         mention_author: bool = ...,
         view: View = ...,
         suppress: bool = ...,
+        silent: bool = ...,
     ) -> Message:
         ...
 
@@ -1357,6 +1383,7 @@ class Messageable:
         mention_author: bool = ...,
         view: View = ...,
         suppress: bool = ...,
+        silent: bool = ...,
     ) -> Message:
         ...
 
@@ -1377,6 +1404,7 @@ class Messageable:
         mention_author=None,
         view=None,
         suppress=None,
+        silent=None,
     ):
         """|coro|
 
@@ -1450,6 +1478,10 @@ class Messageable:
             .. versionadded:: 2.0
         suppress: :class:`bool`
             Whether to suppress embeds for the message.
+        slient: :class:`bool`
+            Whether to suppress push and desktop notifications for the message.
+
+            .. versionadded:: 2.4
 
         Returns
         -------
@@ -1489,7 +1521,10 @@ class Messageable:
                 )
             embeds = [embed.to_dict() for embed in embeds]
 
-        flags = MessageFlags.suppress_embeds if suppress else MessageFlags.DEFAULT_VALUE
+        flags = MessageFlags(
+            suppress_embeds=bool(suppress),
+            suppress_notifications=bool(silent),
+        ).value
 
         if stickers is not None:
             stickers = [sticker.id for sticker in stickers]
@@ -1512,7 +1547,8 @@ class Messageable:
                 reference = reference.to_message_reference_dict()
             except AttributeError:
                 raise InvalidArgument(
-                    "reference parameter must be Message, MessageReference, or PartialMessage"
+                    "reference parameter must be Message, MessageReference, or"
+                    " PartialMessage"
                 ) from None
 
         if view:
