@@ -179,7 +179,7 @@ class ApplicationCommandMixin(ABC):
         self,
         name: str,
         guild_ids: list[int] | None = None,
-        type: type[ApplicationCommand] = SlashCommand,
+        type: type[ApplicationCommand] = ApplicationCommand,
     ) -> ApplicationCommand | None:
         """Get a :class:`.ApplicationCommand` from the internal list
         of commands.
@@ -189,23 +189,39 @@ class ApplicationCommandMixin(ABC):
         Parameters
         ----------
         name: :class:`str`
-            The name of the command to get.
+            The qualified name of the command to get.
         guild_ids: List[:class:`int`]
             The guild ids associated to the command to get.
         type: Type[:class:`.ApplicationCommand`]
-            The type of the command to get. Defaults to :class:`.SlashCommand`.
+            The type of the command to get. Defaults to :class:`.ApplicationCommand`.
 
         Returns
         -------
         Optional[:class:`.ApplicationCommand`]
             The command that was requested. If not found, returns ``None``.
         """
-
-        for command in self._application_commands.values():
+        commands = self._application_commands.values()
+        for command in commands:
             if command.name == name and isinstance(command, type):
                 if guild_ids is not None and command.guild_ids != guild_ids:
                     return
                 return command
+            elif (names := name.split())[0] == command.name and isinstance(
+                command, SlashCommandGroup
+            ):
+                while len(names) > 1:
+                    command = get(commands, name=names.pop(0))
+                    if not isinstance(command, SlashCommandGroup) or (
+                        guild_ids is not None and command.guild_ids != guild_ids
+                    ):
+                        return
+                    commands = command.subcommands
+                command = get(commands, name=names.pop())
+                if not isinstance(command, type) or (
+                    guild_ids is not None and command.guild_ids != guild_ids
+                ):
+                    return
+                return command
 
     async def get_desynced_commands(
         self,
@@ -259,6 +275,7 @@ class ApplicationCommandMixin(ABC):
                 as_dict = cmd.to_dict()
                 to_check = {
                     "dm_permission": None,
+                    "nsfw": None,
                     "default_member_permissions": None,
                     "name": None,
                     "description": None,
@@ -489,7 +506,8 @@ class ApplicationCommandMixin(ABC):
             if kwargs.pop("_log", True):
                 if method == "bulk":
                     _log.debug(
-                        f"Bulk updating commands {[c['name'] for c in args[0]]} for guild {guild_id}"
+                        f"Bulk updating commands {[c['name'] for c in args[0]]} for"
+                        f" guild {guild_id}"
                     )
                 # TODO: Find where "cmd" is defined
                 elif method == "upsert":
@@ -620,7 +638,8 @@ class ApplicationCommandMixin(ABC):
             )
             if not cmd:
                 raise ValueError(
-                    f"Registered command {i['name']}, type {i.get('type')} not found in pending commands"
+                    f"Registered command {i['name']}, type {i.get('type')} not found in"
+                    " pending commands"
                 )
             cmd.id = i["id"]
             self._application_commands[cmd.id] = cmd
@@ -645,7 +664,15 @@ class ApplicationCommandMixin(ABC):
         register all commands.
 
         By default, this coroutine is called inside the :func:`.on_connect` event. If you choose to override the
-        :func:`.on_connect` event, then you should invoke this coroutine as well.
+        :func:`.on_connect` event, then you should invoke this coroutine as well such as the follwing:
+
+        .. code-block:: python
+
+            @bot.event
+            async def on_connect():
+                if bot.auto_sync_commands:
+                    await bot.sync_commands()
+                print(f"{bot.user.name} connected.")
 
         .. note::
             If you remove all guild commands from a particular guild, the library may not be able to detect and update
@@ -807,7 +834,6 @@ class ApplicationCommandMixin(ABC):
                     if guild_id is None:
                         await self.sync_commands()
                     else:
-
                         await self.sync_commands(check_guilds=[guild_id])
                 return self._bot.dispatch("unknown_application_command", interaction)
 
@@ -1500,7 +1526,7 @@ class Bot(BotBase, Client):
 
         .. versionadded:: 2.0
     auto_sync_commands: :class:`bool`
-        Whether to automatically sync slash commands. This will call sync_commands in on_connect, and in
+        Whether to automatically sync slash commands. This will call :meth:`~.Bot.sync_commands` in :func:`discord.on_connect`, and in
         :attr:`.process_application_commands` if the command is not found. Defaults to ``True``.
 
         .. versionadded:: 2.0
