@@ -26,19 +26,7 @@ DEALINGS IN THE SOFTWARE.
 from __future__ import annotations
 
 import datetime
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Final,
-    List,
-    Mapping,
-    Optional,
-    Protocol,
-    Type,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Final, Mapping, Protocol, TypeVar, Union
 
 from . import utils
 from .colour import Colour
@@ -64,14 +52,16 @@ EmptyEmbed: Final = _EmptyEmbed()
 
 
 class EmbedProxy:
-    def __init__(self, layer: Dict[str, Any]):
+    def __init__(self, layer: dict[str, Any]):
         self.__dict__.update(layer)
 
     def __len__(self) -> int:
         return len(self.__dict__)
 
     def __repr__(self) -> str:
-        inner = ", ".join((f"{k}={v!r}" for k, v in self.__dict__.items() if not k.startswith("_")))
+        inner = ", ".join(
+            (f"{k}={v!r}" for k, v in self.__dict__.items() if not k.startswith("_"))
+        )
         return f"EmbedProxy({inner})"
 
     def __getattr__(self, attr: str) -> _EmptyEmbed:
@@ -128,13 +118,13 @@ class EmbedField:
         Whether the field should be displayed inline.
     """
 
-    def __init__(self, name: str, value: str, inline: Optional[bool] = False):
+    def __init__(self, name: str, value: str, inline: bool | None = False):
         self.name = name
         self.value = value
         self.inline = inline
 
     @classmethod
-    def from_dict(cls: Type[E], data: Mapping[str, Any]) -> E:
+    def from_dict(cls: type[E], data: Mapping[str, Any]) -> E:
         """Converts a :class:`dict` to a :class:`EmbedField` provided it is in the
         format that Discord expects it to be in.
 
@@ -145,7 +135,7 @@ class EmbedField:
         __ DiscordDocsEF_
 
         Parameters
-        -----------
+        ----------
         data: :class:`dict`
             The dictionary to convert into an EmbedField object.
         """
@@ -157,8 +147,14 @@ class EmbedField:
 
         return self
 
-    def to_dict(self) -> Dict[str, Union[str, bool]]:
-        """Converts this EmbedField object into a dict."""
+    def to_dict(self) -> dict[str, str | bool]:
+        """Converts this EmbedField object into a dict.
+
+        Returns
+        -------
+        Dict[:class:`str`, Union[:class:`str`, :class:`bool`]]
+            A dictionary of :class:`str` embed field keys bound to the respective value.
+        """
         return {
             "name": self.name,
             "value": self.value,
@@ -192,7 +188,7 @@ class Embed:
     cast to :class:`str` for you.
 
     Attributes
-    -----------
+    ----------
     title: :class:`str`
         The title of the embed.
         This can be set during initialisation.
@@ -242,16 +238,15 @@ class Embed:
     def __init__(
         self,
         *,
-        colour: Union[int, Colour, _EmptyEmbed] = EmptyEmbed,
-        color: Union[int, Colour, _EmptyEmbed] = EmptyEmbed,
+        colour: int | Colour | _EmptyEmbed = EmptyEmbed,
+        color: int | Colour | _EmptyEmbed = EmptyEmbed,
         title: MaybeEmpty[Any] = EmptyEmbed,
         type: EmbedType = "rich",
         url: MaybeEmpty[Any] = EmptyEmbed,
         description: MaybeEmpty[Any] = EmptyEmbed,
         timestamp: datetime.datetime = None,
-        fields: Optional[List[EmbedField]] = None,
+        fields: list[EmbedField] | None = None,
     ):
-
         self.colour = colour if colour is not EmptyEmbed else color
         self.title = title
         self.type = type
@@ -269,10 +264,10 @@ class Embed:
 
         if timestamp:
             self.timestamp = timestamp
-        self._fields: List[EmbedField] = fields or []
+        self._fields: list[EmbedField] = fields or []
 
     @classmethod
-    def from_dict(cls: Type[E], data: Mapping[str, Any]) -> E:
+    def from_dict(cls: type[E], data: Mapping[str, Any]) -> E:
         """Converts a :class:`dict` to a :class:`Embed` provided it is in the
         format that Discord expects it to be in.
 
@@ -283,9 +278,14 @@ class Embed:
         __ DiscordDocs_
 
         Parameters
-        -----------
+        ----------
         data: :class:`dict`
             The dictionary to convert into an embed.
+
+        Returns
+        -------
+        :class:`Embed`
+            The converted embed object.
         """
         # we are bypassing __init__ here since it doesn't apply here
         self: E = cls.__new__(cls)
@@ -341,7 +341,13 @@ class Embed:
         return self
 
     def copy(self: E) -> E:
-        """Returns a shallow copy of the embed."""
+        """Creates a shallow copy of the :class:`Embed` object.
+
+        Returns
+        -------
+        :class:`Embed`
+            The copied embed object.
+        """
         return self.__class__.from_dict(self.to_dict())
 
     def __len__(self) -> int:
@@ -388,14 +394,15 @@ class Embed:
         return getattr(self, "_colour", EmptyEmbed)
 
     @colour.setter
-    def colour(self, value: Union[int, Colour, _EmptyEmbed]):  # type: ignore
+    def colour(self, value: int | Colour | _EmptyEmbed):  # type: ignore
         if isinstance(value, (Colour, _EmptyEmbed)):
             self._colour = value
         elif isinstance(value, int):
             self._colour = Colour(value=value)
         else:
             raise TypeError(
-                f"Expected discord.Colour, int, or Embed.Empty but received {value.__class__.__name__} instead."
+                "Expected discord.Colour, int, or Embed.Empty but received"
+                f" {value.__class__.__name__} instead."
             )
 
     color = colour
@@ -413,7 +420,10 @@ class Embed:
         elif isinstance(value, _EmptyEmbed):
             self._timestamp = value
         else:
-            raise TypeError(f"Expected datetime.datetime or Embed.Empty received {value.__class__.__name__} instead")
+            raise TypeError(
+                "Expected datetime.datetime or Embed.Empty received"
+                f" {value.__class__.__name__} instead"
+            )
 
     @property
     def footer(self) -> _EmbedFooterProxy:
@@ -437,7 +447,7 @@ class Embed:
         chaining.
 
         Parameters
-        -----------
+        ----------
         text: :class:`str`
             The footer text.
             Must be 2048 characters or fewer.
@@ -494,7 +504,7 @@ class Embed:
             Passing :attr:`Empty` removes the image.
 
         Parameters
-        -----------
+        ----------
         url: :class:`str`
             The source URL for the image. Only HTTP(S) is supported.
         """
@@ -551,7 +561,7 @@ class Embed:
             Passing :attr:`Empty` removes the thumbnail.
 
         Parameters
-        -----------
+        ----------
         url: :class:`str`
             The source URL for the thumbnail. Only HTTP(S) is supported.
         """
@@ -630,7 +640,7 @@ class Embed:
         chaining.
 
         Parameters
-        -----------
+        ----------
         name: :class:`str`
             The name of the author.
             Must be 256 characters or fewer.
@@ -668,7 +678,7 @@ class Embed:
         return self
 
     @property
-    def fields(self) -> List[EmbedField]:
+    def fields(self) -> list[EmbedField]:
         """Returns a :class:`list` of :class:`EmbedField` objects denoting the field contents.
 
         See :meth:`add_field` for possible values you can access.
@@ -678,7 +688,7 @@ class Embed:
         return self._fields
 
     @fields.setter
-    def fields(self, value: List[EmbedField]) -> None:
+    def fields(self, value: list[EmbedField]) -> None:
         """Sets the fields for the embed. This overwrites any existing fields.
 
         Parameters
@@ -713,7 +723,7 @@ class Embed:
         chaining. There must be 25 fields or fewer.
 
         Parameters
-        -----------
+        ----------
         name: :class:`str`
             The name of the field.
             Must be 256 characters or fewer.
@@ -727,7 +737,9 @@ class Embed:
 
         return self
 
-    def insert_field_at(self: E, index: int, *, name: Any, value: Any, inline: bool = True) -> E:
+    def insert_field_at(
+        self: E, index: int, *, name: Any, value: Any, inline: bool = True
+    ) -> E:
         """Inserts a field before a specified index to the embed.
 
         This function returns the class instance to allow for fluent-style
@@ -736,7 +748,7 @@ class Embed:
         .. versionadded:: 1.2
 
         Parameters
-        -----------
+        ----------
         index: :class:`int`
             The index of where to insert the field.
         name: :class:`str`
@@ -771,7 +783,7 @@ class Embed:
             shift to fill the gap just like a regular list.
 
         Parameters
-        -----------
+        ----------
         index: :class:`int`
             The index of the field to remove.
         """
@@ -780,7 +792,9 @@ class Embed:
         except IndexError:
             pass
 
-    def set_field_at(self: E, index: int, *, name: Any, value: Any, inline: bool = True) -> E:
+    def set_field_at(
+        self: E, index: int, *, name: Any, value: Any, inline: bool = True
+    ) -> E:
         """Modifies a field to the embed object.
 
         The index must point to a valid pre-existing field. There must be 25 fields or fewer.
@@ -789,7 +803,7 @@ class Embed:
         chaining.
 
         Parameters
-        -----------
+        ----------
         index: :class:`int`
             The index of the field to modify.
         name: :class:`str`
@@ -802,7 +816,7 @@ class Embed:
             Whether the field should be displayed inline.
 
         Raises
-        -------
+        ------
         IndexError
             An invalid index was provided.
         """
@@ -818,7 +832,13 @@ class Embed:
         return self
 
     def to_dict(self) -> EmbedData:
-        """Converts this embed object into a dict."""
+        """Converts this embed object into a dict.
+
+        Returns
+        -------
+        Dict[:class:`str`, Union[:class:`str`, :class:`int`, :class:`bool`]]
+            A dictionary of :class:`str` embed keys bound to the respective value.
+        """
 
         # add in the raw data into the dict
         result = {
@@ -847,9 +867,13 @@ class Embed:
         else:
             if timestamp:
                 if timestamp.tzinfo:
-                    result["timestamp"] = timestamp.astimezone(tz=datetime.timezone.utc).isoformat()
+                    result["timestamp"] = timestamp.astimezone(
+                        tz=datetime.timezone.utc
+                    ).isoformat()
                 else:
-                    result["timestamp"] = timestamp.replace(tzinfo=datetime.timezone.utc).isoformat()
+                    result["timestamp"] = timestamp.replace(
+                        tzinfo=datetime.timezone.utc
+                    ).isoformat()
 
         # add in the non-raw attribute ones
         if self.type:
