@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Union
 
 if TYPE_CHECKING:
     from aiohttp import ClientResponse, ClientWebSocketResponse
@@ -73,8 +73,6 @@ class DiscordException(Exception):
     Ideally speaking, this could be caught to handle any exceptions raised from this library.
     """
 
-    pass
-
 
 class ClientException(DiscordException):
     """Exception that's raised when an operation in the :class:`Client` fails.
@@ -82,14 +80,10 @@ class ClientException(DiscordException):
     These are usually for exceptions that happened due to user input.
     """
 
-    pass
-
 
 class NoMoreItems(DiscordException):
     """Exception that is raised when an async iteration operation has no more items."""
 
-    pass
-
 
 class GatewayNotFound(DiscordException):
     """An exception that is raised when the gateway for Discord could not be found"""
@@ -102,17 +96,15 @@ class GatewayNotFound(DiscordException):
 class ValidationError(DiscordException):
     """An Exception that is raised when there is a Validation Error."""
 
-    pass
 
-
-def _flatten_error_dict(d: Dict[str, Any], key: str = "") -> Dict[str, str]:
-    items: List[Tuple[str, str]] = []
+def _flatten_error_dict(d: dict[str, Any], key: str = "") -> dict[str, str]:
+    items: list[tuple[str, str]] = []
     for k, v in d.items():
         new_key = f"{key}.{k}" if key else k
 
         if isinstance(v, dict):
             try:
-                _errors: List[Dict[str, Any]] = v["_errors"]
+                _errors: list[dict[str, Any]] = v["_errors"]
             except KeyError:
                 items.extend(_flatten_error_dict(v, new_key).items())
             else:
@@ -127,7 +119,7 @@ class HTTPException(DiscordException):
     """Exception that's raised when an HTTP request operation fails.
 
     Attributes
-    ------------
+    ----------
     response: :class:`aiohttp.ClientResponse`
         The response of the failed HTTP request. This is an
         instance of :class:`aiohttp.ClientResponse`. In some cases
@@ -141,7 +133,7 @@ class HTTPException(DiscordException):
         The Discord specific error code for the failure.
     """
 
-    def __init__(self, response: _ResponseType, message: Optional[Union[str, Dict[str, Any]]]):
+    def __init__(self, response: _ResponseType, message: str | dict[str, Any] | None):
         self.response: _ResponseType = response
         self.status: int = response.status  # type: ignore
         self.code: int
@@ -173,8 +165,6 @@ class Forbidden(HTTPException):
     Subclass of :exc:`HTTPException`
     """
 
-    pass
-
 
 class NotFound(HTTPException):
     """Exception that's raised for when status code 404 occurs.
@@ -182,8 +172,6 @@ class NotFound(HTTPException):
     Subclass of :exc:`HTTPException`
     """
 
-    pass
-
 
 class DiscordServerError(HTTPException):
     """Exception that's raised for when a 500 range status code occurs.
@@ -193,28 +181,22 @@ class DiscordServerError(HTTPException):
     .. versionadded:: 1.5
     """
 
-    pass
-
 
 class InvalidData(ClientException):
     """Exception that's raised when the library encounters unknown
     or invalid data from Discord.
     """
 
-    pass
-
 
 class InvalidArgument(ClientException):
     """Exception that's raised when an argument to a function
     is invalid some way (e.g. wrong value or wrong type).
 
-    This could be considered the analogous of ``ValueError`` and
+    This could be considered the parallel of ``ValueError`` and
     ``TypeError`` except inherited from :exc:`ClientException` and thus
     :exc:`DiscordException`.
     """
 
-    pass
-
 
 class LoginFailure(ClientException):
     """Exception that's raised when the :meth:`Client.login` function
@@ -222,15 +204,13 @@ class LoginFailure(ClientException):
     failure.
     """
 
-    pass
-
 
 class ConnectionClosed(ClientException):
     """Exception that's raised when the gateway connection is
     closed for reasons that could not be handled internally.
 
     Attributes
-    -----------
+    ----------
     code: :class:`int`
         The close code of the websocket.
     reason: :class:`str`
@@ -243,42 +223,43 @@ class ConnectionClosed(ClientException):
         self,
         socket: ClientWebSocketResponse,
         *,
-        shard_id: Optional[int],
-        code: Optional[int] = None,
+        shard_id: int | None,
+        code: int | None = None,
     ):
         # This exception is just the same exception except
         # reconfigured to subclass ClientException for users
         self.code: int = code or socket.close_code or -1
         # aiohttp doesn't seem to consistently provide close reason
         self.reason: str = ""
-        self.shard_id: Optional[int] = shard_id
+        self.shard_id: int | None = shard_id
         super().__init__(f"Shard ID {self.shard_id} WebSocket closed with {self.code}")
 
 
 class PrivilegedIntentsRequired(ClientException):
-    """Exception that's raised when the gateway is requesting privileged intents
-    but they're not ticked in the developer page yet.
+    """Exception that's raised when the gateway is requesting privileged intents, but
+    they're not ticked in the developer page yet.
 
     Go to https://discord.com/developers/applications/ and enable the intents
-    that are required. Currently these are as follows:
+    that are required. Currently, these are as follows:
 
     - :attr:`Intents.members`
     - :attr:`Intents.presences`
     - :attr:`Intents.message_content`
 
     Attributes
-    -----------
+    ----------
     shard_id: Optional[:class:`int`]
         The shard ID that got closed if applicable.
     """
 
-    def __init__(self, shard_id: Optional[int]):
-        self.shard_id: Optional[int] = shard_id
+    def __init__(self, shard_id: int | None):
+        self.shard_id: int | None = shard_id
         msg = (
-            "Shard ID %s is requesting privileged intents that have not been explicitly enabled in the "
-            "developer portal. It is recommended to go to https://discord.com/developers/applications/ "
-            "and explicitly enable the privileged intents within your application's page. If this is not "
-            "possible, then consider disabling the privileged intents instead."
+            "Shard ID %s is requesting privileged intents that have not been explicitly"
+            " enabled in the developer portal. It is recommended to go to"
+            " https://discord.com/developers/applications/ and explicitly enable the"
+            " privileged intents within your application's page. If this is not"
+            " possible, then consider disabling the privileged intents instead."
         )
         super().__init__(msg % shard_id)
 
@@ -292,7 +273,7 @@ class InteractionResponded(ClientException):
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     interaction: :class:`Interaction`
         The interaction that's already been responded to.
     """
@@ -308,16 +289,18 @@ class ExtensionError(DiscordException):
     This inherits from :exc:`~discord.DiscordException`.
 
     Attributes
-    ------------
+    ----------
     name: :class:`str`
         The extension that had an error.
     """
 
-    def __init__(self, message: Optional[str] = None, *args: Any, name: str) -> None:
+    def __init__(self, message: str | None = None, *args: Any, name: str) -> None:
         self.name: str = name
         message = message or f"Extension {name!r} had an error."
         # clean-up @everyone and @here mentions
-        m = message.replace("@everyone", "@\u200beveryone").replace("@here", "@\u200bhere")
+        m = message.replace("@everyone", "@\u200beveryone").replace(
+            "@here", "@\u200bhere"
+        )
         super().__init__(m, *args)
 
 
@@ -357,7 +340,7 @@ class ExtensionFailed(ExtensionError):
     This inherits from :exc:`ExtensionError`
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The extension that had the error.
     original: :exc:`Exception`
@@ -367,7 +350,10 @@ class ExtensionFailed(ExtensionError):
 
     def __init__(self, name: str, original: Exception) -> None:
         self.original: Exception = original
-        msg = f"Extension {name!r} raised an error: {original.__class__.__name__}: {original}"
+        msg = (
+            f"Extension {name!r} raised an error: {original.__class__.__name__}:"
+            f" {original}"
+        )
         super().__init__(msg, name=name)
 
 
@@ -380,7 +366,7 @@ class ExtensionNotFound(ExtensionError):
         Made the ``original`` attribute always None.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The extension that had the error.
     """
@@ -399,7 +385,6 @@ class ApplicationCommandError(DiscordException):
     in a special way as they are caught and passed into a special event
     from :class:`.Bot`\, :func:`.on_command_error`.
     """
-    pass
 
 
 class CheckFailure(ApplicationCommandError):
@@ -408,8 +393,6 @@ class CheckFailure(ApplicationCommandError):
     This inherits from :exc:`ApplicationCommandError`
     """
 
-    pass
-
 
 class ApplicationCommandInvokeError(ApplicationCommandError):
     """Exception raised when the command being invoked raised an exception.
@@ -417,7 +400,7 @@ class ApplicationCommandInvokeError(ApplicationCommandError):
     This inherits from :exc:`ApplicationCommandError`
 
     Attributes
-    -----------
+    ----------
     original: :exc:`Exception`
         The original exception that was raised. You can also get this via
         the ``__cause__`` attribute.
@@ -425,4 +408,6 @@ class ApplicationCommandInvokeError(ApplicationCommandError):
 
     def __init__(self, e: Exception) -> None:
         self.original: Exception = e
-        super().__init__(f"Application Command raised an exception: {e.__class__.__name__}: {e}")
+        super().__init__(
+            f"Application Command raised an exception: {e.__class__.__name__}: {e}"
+        )
