@@ -104,7 +104,7 @@ class Interaction:
     application_id: :class:`int`
         The application ID that the interaction was for.
     user: Optional[Union[:class:`User`, :class:`Member`]]
-        The user or member that sent the interaction.
+        The user or member that sent the interaction. Will be `None` in PING interactions.
     message: Optional[:class:`Message`]
         The message that sent this interaction.
     token: :class:`str`
@@ -154,13 +154,14 @@ class Interaction:
 
     def _from_data(self, data: InteractionPayload):
         self.id: int = int(data["id"])
-        self.type: InteractionType = try_enum(InteractionType, data["type"])
+        self.type: InteractionType = try_enum(InteractionType, data.get("type"))
         self.data: InteractionData | None = data.get("data")
-        self.token: str = data["token"]
-        self.version: int = data["version"]
+        self.token: str = data.get("token")
+        self.version: int = data.get("version")
         self.channel_id: int | None = utils._get_as_snowflake(data, "channel_id")
         self.guild_id: int | None = utils._get_as_snowflake(data, "guild_id")
-        self.application_id: int = int(data["application_id"])
+        app_id = data.get("application_id")
+        self.application_id: int = int(app_id) if app_id is not None else -1
         self.locale: str | None = data.get("locale")
         self.guild_locale: str | None = data.get("guild_locale")
         self.custom_id: str | None = (
@@ -208,25 +209,25 @@ class Interaction:
 
     @property
     def client(self) -> Client:
-        """:class:`Client`: Returns the client that sent the interaction."""
+        """Returns the client that sent the interaction."""
         return self._state._get_client()
 
     @property
     def guild(self) -> Guild | None:
-        """Optional[:class:`Guild`]: The guild the interaction was sent from."""
+        """The guild the interaction was sent from."""
         return self._state and self._state._get_guild(self.guild_id)
 
     def is_command(self) -> bool:
-        """:class:`bool`: Indicates whether the interaction is an application command."""
+        """Indicates whether the interaction is an application command."""
         return self.type == InteractionType.application_command
 
     def is_component(self) -> bool:
-        """:class:`bool`: Indicates whether the interaction is a message component."""
+        """Indicates whether the interaction is a message component."""
         return self.type == InteractionType.component
 
     @utils.cached_slot_property("_cs_channel")
     def channel(self) -> InteractionChannel | None:
-        """Optional[Union[:class:`abc.GuildChannel`, :class:`PartialMessageable`, :class:`Thread`]]: The channel the
+        """The channel the
         interaction was sent from.
 
         Note that due to a Discord limitation, DM channels are not resolved since there is
@@ -249,7 +250,7 @@ class Interaction:
 
     @property
     def permissions(self) -> Permissions:
-        """:class:`Permissions`: The resolved permissions of the member in the channel, including overwrites.
+        """The resolved permissions of the member in the channel, including overwrites.
 
         In a non-guild context where this doesn't apply, an empty permissions object is returned.
         """
@@ -257,12 +258,12 @@ class Interaction:
 
     @utils.cached_slot_property("_cs_app_permissions")
     def app_permissions(self) -> Permissions:
-        """:class:`Permissions`: The resolved permissions of the application in the channel, including overwrites."""
+        """The resolved permissions of the application in the channel, including overwrites."""
         return Permissions(self._app_permissions)
 
     @utils.cached_slot_property("_cs_response")
     def response(self) -> InteractionResponse:
-        """:class:`InteractionResponse`: Returns an object responsible for handling responding to the interaction.
+        """Returns an object responsible for handling responding to the interaction.
 
         A response can only be done once. If secondary messages need to be sent, consider using :attr:`followup`
         instead.
@@ -271,7 +272,7 @@ class Interaction:
 
     @utils.cached_slot_property("_cs_followup")
     def followup(self) -> Webhook:
-        """:class:`Webhook`: Returns the followup webhook for followup interactions."""
+        """Returns the followup webhook for followup interactions."""
         payload = {
             "id": self.application_id,
             "type": 3,
@@ -325,7 +326,7 @@ class Interaction:
         self._original_response = message
         return message
 
-    @utils.deprecated("Interaction.original_response", "2.1")
+    @utils.deprecated("Interaction.original_response", "2.2")
     async def original_message(self):
         """An alias for :meth:`original_response`.
 
@@ -341,7 +342,7 @@ class Interaction:
         ClientException
             The channel for the message could not be resolved.
         """
-        return self.original_response()
+        return await self.original_response()
 
     async def edit_original_response(
         self,
@@ -447,7 +448,7 @@ class Interaction:
 
         return message
 
-    @utils.deprecated("Interaction.edit_original_response", "2.1")
+    @utils.deprecated("Interaction.edit_original_response", "2.2")
     async def edit_original_message(self, **kwargs):
         """An alias for :meth:`edit_original_response`.
 
@@ -467,7 +468,7 @@ class Interaction:
         ValueError
             The length of ``embeds`` was invalid.
         """
-        return self.edit_original_response(**kwargs)
+        return await self.edit_original_response(**kwargs)
 
     async def delete_original_response(self, *, delay: float | None = None) -> None:
         """|coro|
@@ -505,7 +506,7 @@ class Interaction:
         else:
             await func
 
-    @utils.deprecated("Interaction.delete_original_response", "2.1")
+    @utils.deprecated("Interaction.delete_original_response", "2.2")
     async def delete_original_message(self, **kwargs):
         """An alias for :meth:`delete_original_response`.
 
@@ -516,7 +517,7 @@ class Interaction:
         Forbidden
             Deleted a message that is not yours.
         """
-        return self.delete_original_response(**kwargs)
+        return await self.delete_original_response(**kwargs)
 
     def to_dict(self) -> dict[str, Any]:
         """
@@ -586,7 +587,7 @@ class InteractionResponse:
         self._response_lock = asyncio.Lock()
 
     def is_done(self) -> bool:
-        """:class:`bool`: Indicates whether an interaction response has been done before.
+        """Indicates whether an interaction response has been done before.
 
         An interaction can only be responded to once.
         """
