@@ -26,7 +26,7 @@ DEALINGS IN THE SOFTWARE.
 from __future__ import annotations
 
 import re
-from typing import TYPE_CHECKING, Any, TypeVar
+from typing import TYPE_CHECKING, Any, TypedDict, TypeVar
 
 from . import utils
 from .asset import Asset, AssetMixin
@@ -160,6 +160,16 @@ class PartialEmoji(_EmojiTag, AssetMixin):
     def _to_partial(self) -> PartialEmoji:
         return self
 
+    def _to_forum_tag_payload(
+        self,
+    ) -> TypedDict("TagPayload", {"emoji_id": int, "emoji_name": None}) | TypedDict(
+        "TagPayload", {"emoji_id": None, "emoji_name": str}
+    ):
+        if self.id is None:
+            return {"emoji_id": None, "emoji_name": self.name}
+        else:
+            return {"emoji_id": self.id, "emoji_name": None}
+
     @classmethod
     def with_state(
         cls: type[PE],
@@ -174,11 +184,12 @@ class PartialEmoji(_EmojiTag, AssetMixin):
         return self
 
     def __str__(self) -> str:
+        # Emoji won't render if the name is empty
+        name = self.name or "_"
         if self.id is None:
-            return self.name
-        if self.animated:
-            return f"<a:{self.name}:{self.id}>"
-        return f"<:{self.name}:{self.id}>"
+            return name
+        animated_tag = "a" if self.animated else ""
+        return f"<{animated_tag}:{name}:{self.id}>"
 
     def __repr__(self):
         return f"<{self.__class__.__name__} animated={self.animated} name={self.name!r} id={self.id}>"
@@ -198,11 +209,11 @@ class PartialEmoji(_EmojiTag, AssetMixin):
         return hash((self.id, self.name))
 
     def is_custom_emoji(self) -> bool:
-        """:class:`bool`: Checks if this is a custom non-Unicode emoji."""
+        """Checks if this is a custom non-Unicode emoji."""
         return self.id is not None
 
     def is_unicode_emoji(self) -> bool:
-        """:class:`bool`: Checks if this is a Unicode emoji."""
+        """Checks if this is a Unicode emoji."""
         return self.id is None
 
     def _as_reaction(self) -> str:
@@ -212,7 +223,7 @@ class PartialEmoji(_EmojiTag, AssetMixin):
 
     @property
     def created_at(self) -> datetime | None:
-        """Optional[:class:`datetime.datetime`]: Returns the emoji's creation time in UTC, or None if Unicode emoji.
+        """Returns the emoji's creation time in UTC, or None if Unicode emoji.
 
         .. versionadded:: 1.6
         """
@@ -223,7 +234,7 @@ class PartialEmoji(_EmojiTag, AssetMixin):
 
     @property
     def url(self) -> str:
-        """:class:`str`: Returns the URL of the emoji, if it is custom.
+        """Returns the URL of the emoji, if it is custom.
 
         If this isn't a custom emoji then an empty string is returned
         """
