@@ -22,10 +22,7 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 import io
-import os
 import subprocess
-import threading
-from typing import IO, Optional
 
 from .core import CREATE_NO_WINDOW, Filters, Sink, default_filters
 from .errors import MP3SinkError
@@ -58,7 +55,9 @@ class MP3Sink(Sink):
             Formatting the audio failed.
         """
         if self.vc.recording:
-            raise MP3SinkError("Audio may only be formatted after recording is finished.")
+            raise MP3SinkError(
+                "Audio may only be formatted after recording is finished."
+            )
         args = [
             "ffmpeg",
             "-f",
@@ -83,7 +82,9 @@ class MP3Sink(Sink):
         except FileNotFoundError:
             raise MP3SinkError("ffmpeg was not found.") from None
         except subprocess.SubprocessError as exc:
-            raise MP3SinkError("Popen failed: {0.__class__.__name__}: {0}".format(exc)) from exc
+            raise MP3SinkError(
+                "Popen failed: {0.__class__.__name__}: {0}".format(exc)
+            ) from exc
 
         out = process.communicate(audio.file.read())[0]
         out = io.BytesIO(out)
