@@ -26,7 +26,7 @@ DEALINGS IN THE SOFTWARE.
 from __future__ import annotations
 
 import unicodedata
-from typing import TYPE_CHECKING, List, Literal, Optional, Tuple, Type, Union
+from typing import TYPE_CHECKING, Literal
 
 from .asset import Asset, AssetMixin
 from .enums import StickerFormatType, StickerType, try_enum
@@ -77,7 +77,7 @@ class StickerPack(Hashable):
            Checks if the sticker pack is not equal to another sticker pack.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The name of the sticker pack.
     description: :class:`str`
@@ -113,7 +113,7 @@ class StickerPack(Hashable):
     def _from_data(self, data: StickerPackPayload) -> None:
         self.id: int = int(data["id"])
         stickers = data["stickers"]
-        self.stickers: List[StandardSticker] = [
+        self.stickers: list[StandardSticker] = [
             StandardSticker(state=self._state, data=sticker) for sticker in stickers
         ]
         self.name: str = data["name"]
@@ -125,11 +125,14 @@ class StickerPack(Hashable):
 
     @property
     def banner(self) -> Asset:
-        """:class:`Asset`: The banner asset of the sticker pack."""
+        """The banner asset of the sticker pack."""
         return Asset._from_sticker_banner(self._state, self._banner)
 
     def __repr__(self) -> str:
-        return f"<StickerPack id={self.id} name={self.name!r} description={self.description!r}>"
+        return (
+            "<StickerPack"
+            f" id={self.id} name={self.name!r} description={self.description!r}>"
+        )
 
     def __str__(self) -> str:
         return self.name
@@ -150,6 +153,11 @@ class _StickerTag(Hashable, AssetMixin):
 
             Stickers that use the :attr:`StickerFormatType.lottie` format cannot be read.
 
+        Returns
+        -------
+        :class:`bytes`
+            The content of the asset.
+
         Raises
         ------
         HTTPException
@@ -158,11 +166,6 @@ class _StickerTag(Hashable, AssetMixin):
             The asset was deleted.
         TypeError
             The sticker is a lottie type.
-
-        Returns
-        -------
-        :class:`bytes`
-            The content of the asset.
         """
         if self.format is StickerFormatType.lottie:
             raise TypeError('Cannot read stickers of format "lottie".')
@@ -189,7 +192,7 @@ class StickerItem(_StickerTag):
            Checks if the sticker item is not equal to another sticker item.
 
     Attributes
-    -----------
+    ----------
     name: :class:`str`
         The sticker's name.
     id: :class:`int`
@@ -206,7 +209,9 @@ class StickerItem(_StickerTag):
         self._state: ConnectionState = state
         self.name: str = data["name"]
         self.id: int = int(data["id"])
-        self.format: StickerFormatType = try_enum(StickerFormatType, data["format_type"])
+        self.format: StickerFormatType = try_enum(
+            StickerFormatType, data["format_type"]
+        )
         self.url: str = f"{Asset.BASE}/stickers/{self.id}.{self.format.file_extension}"
 
     def __repr__(self) -> str:
@@ -215,20 +220,20 @@ class StickerItem(_StickerTag):
     def __str__(self) -> str:
         return self.name
 
-    async def fetch(self) -> Union[Sticker, StandardSticker, GuildSticker]:
+    async def fetch(self) -> Sticker | StandardSticker | GuildSticker:
         """|coro|
 
         Attempts to retrieve the full sticker data of the sticker item.
 
-        Raises
-        --------
-        HTTPException
-            Retrieving the sticker failed.
-
         Returns
-        --------
+        -------
         Union[:class:`StandardSticker`, :class:`GuildSticker`]
             The retrieved sticker.
+
+        Raises
+        ------
+        HTTPException
+            Retrieving the sticker failed.
         """
         data: StickerPayload = await self._state.http.get_sticker(self.id)
         cls, _ = _sticker_factory(data["type"])  # type: ignore
@@ -280,7 +285,9 @@ class Sticker(_StickerTag):
         self.id: int = int(data["id"])
         self.name: str = data["name"]
         self.description: str = data["description"]
-        self.format: StickerFormatType = try_enum(StickerFormatType, data["format_type"])
+        self.format: StickerFormatType = try_enum(
+            StickerFormatType, data["format_type"]
+        )
         self.url: str = f"{Asset.BASE}/stickers/{self.id}.{self.format.file_extension}"
 
     def __repr__(self) -> str:
@@ -291,7 +298,7 @@ class Sticker(_StickerTag):
 
     @property
     def created_at(self) -> datetime.datetime:
-        """:class:`datetime.datetime`: Returns the sticker's creation time in UTC."""
+        """Returns the sticker's creation time in UTC."""
         return snowflake_time(self.id)
 
 
@@ -341,31 +348,35 @@ class StandardSticker(Sticker):
         self.type: StickerType = StickerType.standard
 
         try:
-            self.tags: List[str] = [tag.strip() for tag in data["tags"].split(",")]
+            self.tags: list[str] = [tag.strip() for tag in data["tags"].split(",")]
         except KeyError:
             self.tags = []
 
     def __repr__(self) -> str:
-        return f"<StandardSticker id={self.id} name={self.name!r} pack_id={self.pack_id}>"
+        return (
+            f"<StandardSticker id={self.id} name={self.name!r} pack_id={self.pack_id}>"
+        )
 
     async def pack(self) -> StickerPack:
         """|coro|
 
         Retrieves the sticker pack that this sticker belongs to.
 
+        Returns
+        -------
+        :class:`StickerPack`
+            The retrieved sticker pack.
+
         Raises
-        --------
+        ------
         InvalidData
             The corresponding sticker pack was not found.
         HTTPException
             Retrieving the sticker pack failed.
-
-        Returns
-        --------
-        :class:`StickerPack`
-            The retrieved sticker pack.
         """
-        data: ListPremiumStickerPacksPayload = await self._state.http.list_premium_sticker_packs()
+        data: ListPremiumStickerPacksPayload = (
+            await self._state.http.list_premium_sticker_packs()
+        )
         packs = data["sticker_packs"]
         pack = find(lambda d: int(d["id"]) == self.pack_id, packs)
 
@@ -421,16 +432,19 @@ class GuildSticker(Sticker):
         self.available: bool = data["available"]
         self.guild_id: int = int(data["guild_id"])
         user = data.get("user")
-        self.user: Optional[User] = self._state.store_user(user) if user else None
+        self.user: User | None = self._state.store_user(user) if user else None
         self.emoji: str = data["tags"]
         self.type: StickerType = StickerType.guild
 
     def __repr__(self) -> str:
-        return f"<GuildSticker name={self.name!r} id={self.id} guild_id={self.guild_id} user={self.user!r}>"
+        return (
+            "<GuildSticker"
+            f" name={self.name!r} id={self.id} guild_id={self.guild_id} user={self.user!r}>"
+        )
 
     @cached_slot_property("_cs_guild")
-    def guild(self) -> Optional[Guild]:
-        """Optional[:class:`Guild`]: The guild that this sticker is from.
+    def guild(self) -> Guild | None:
+        """The guild that this sticker is from.
         Could be ``None`` if the bot is not in the guild.
 
         .. versionadded:: 2.0
@@ -443,14 +457,14 @@ class GuildSticker(Sticker):
         name: str = MISSING,
         description: str = MISSING,
         emoji: str = MISSING,
-        reason: Optional[str] = None,
+        reason: str | None = None,
     ) -> GuildSticker:
         """|coro|
 
         Edits a :class:`GuildSticker` for the guild.
 
         Parameters
-        -----------
+        ----------
         name: :class:`str`
             The sticker's new name. Must be at least 2 characters.
         description: Optional[:class:`str`]
@@ -460,17 +474,17 @@ class GuildSticker(Sticker):
         reason: :class:`str`
             The reason for editing this sticker. Shows up on the audit log.
 
-        Raises
+        Returns
         -------
+        :class:`GuildSticker`
+            The newly modified sticker.
+
+        Raises
+        ------
         Forbidden
             You are not allowed to edit stickers.
         HTTPException
             An error occurred editing the sticker.
-
-        Returns
-        --------
-        :class:`GuildSticker`
-            The newly modified sticker.
         """
         payload: EditGuildSticker = {}
 
@@ -490,10 +504,12 @@ class GuildSticker(Sticker):
 
             payload["tags"] = emoji
 
-        data: GuildStickerPayload = await self._state.http.modify_guild_sticker(self.guild_id, self.id, payload, reason)
+        data: GuildStickerPayload = await self._state.http.modify_guild_sticker(
+            self.guild_id, self.id, payload, reason
+        )
         return GuildSticker(state=self._state, data=data)
 
-    async def delete(self, *, reason: Optional[str] = None) -> None:
+    async def delete(self, *, reason: str | None = None) -> None:
         """|coro|
 
         Deletes the custom :class:`Sticker` from the guild.
@@ -502,12 +518,12 @@ class GuildSticker(Sticker):
         do this.
 
         Parameters
-        -----------
+        ----------
         reason: Optional[:class:`str`]
             The reason for deleting this sticker. Shows up on the audit log.
 
         Raises
-        -------
+        ------
         Forbidden
             You are not allowed to delete stickers.
         HTTPException
@@ -518,7 +534,7 @@ class GuildSticker(Sticker):
 
 def _sticker_factory(
     sticker_type: Literal[1, 2]
-) -> Tuple[Type[Union[StandardSticker, GuildSticker, Sticker]], StickerType]:
+) -> tuple[type[StandardSticker | GuildSticker | Sticker], StickerType]:
     value = try_enum(StickerType, sticker_type)
     if value == StickerType.standard:
         return StandardSticker, value
