@@ -25,8 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import List, Optional, TypedDict
-
+from .._typed_dict import NotRequired, TypedDict
 from .snowflake import Snowflake
 from .team import Team
 from .user import User
@@ -36,38 +35,27 @@ class BaseAppInfo(TypedDict):
     id: Snowflake
     name: str
     verify_key: str
-    icon: Optional[str]
+    icon: str | None
     summary: str
     description: str
+    terms_of_service_url: NotRequired[str]
+    privacy_policy_url: NotRequired[str]
+    hook: NotRequired[bool]
+    max_participants: NotRequired[int]
 
 
-class _AppInfoOptional(TypedDict, total=False):
-    team: Team
-    guild_id: Snowflake
-    primary_sku_id: Snowflake
-    slug: str
-    terms_of_service_url: str
-    privacy_policy_url: str
-    hook: bool
-    max_participants: int
-
-
-class AppInfo(BaseAppInfo, _AppInfoOptional):
-    rpc_origins: List[str]
+class AppInfo(BaseAppInfo):
+    team: NotRequired[Team]
+    guild_id: NotRequired[Snowflake]
+    primary_sku_id: NotRequired[Snowflake]
+    slug: NotRequired[str]
+    rpc_origins: list[str]
     owner: User
     bot_public: bool
     bot_require_code_grant: bool
 
 
-class _PartialAppInfoOptional(TypedDict, total=False):
-    rpc_origins: List[str]
-    cover_image: str
-    hook: bool
-    terms_of_service_url: str
-    privacy_policy_url: str
-    max_participants: int
-    flags: int
-
-
-class PartialAppInfo(_PartialAppInfoOptional, BaseAppInfo):
-    pass
+class PartialAppInfo(BaseAppInfo):
+    rpc_origins: NotRequired[list[str]]
+    cover_image: NotRequired[str]
+    flags: NotRequired[int]
