@@ -27,7 +27,7 @@ from __future__ import annotations
 
 import inspect
 import os
-from typing import TYPE_CHECKING, Callable, Optional, Tuple, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Callable, TypeVar
 
 from ..components import Button as ButtonComponent
 from ..enums import ButtonStyle, ComponentType
@@ -53,7 +53,7 @@ class Button(Item[V]):
     .. versionadded:: 2.0
 
     Parameters
-    ------------
+    ----------
     style: :class:`discord.ButtonStyle`
         The style of the button.
     custom_id: Optional[:class:`str`]
@@ -64,7 +64,7 @@ class Button(Item[V]):
     disabled: :class:`bool`
         Whether the button is disabled or not.
     label: Optional[:class:`str`]
-        The label of the button, if any.
+        The label of the button, if any. Maximum of 80 chars.
     emoji: Optional[Union[:class:`.PartialEmoji`, :class:`.Emoji`, :class:`str`]]
         The emoji of the button, if available.
     row: Optional[:class:`int`]
@@ -75,7 +75,7 @@ class Button(Item[V]):
         ordering. The row number must be between 0 and 4 (i.e. zero indexed).
     """
 
-    __item_repr_attributes__: Tuple[str, ...] = (
+    __item_repr_attributes__: tuple[str, ...] = (
         "style",
         "url",
         "disabled",
@@ -88,12 +88,12 @@ class Button(Item[V]):
         self,
         *,
         style: ButtonStyle = ButtonStyle.secondary,
-        label: Optional[str] = None,
+        label: str | None = None,
         disabled: bool = False,
-        custom_id: Optional[str] = None,
-        url: Optional[str] = None,
-        emoji: Optional[Union[str, Emoji, PartialEmoji]] = None,
-        row: Optional[int] = None,
+        custom_id: str | None = None,
+        url: str | None = None,
+        emoji: str | Emoji | PartialEmoji | None = None,
+        row: int | None = None,
     ):
         super().__init__()
         if label and len(str(label)) > 80:
@@ -104,7 +104,9 @@ class Button(Item[V]):
             raise TypeError("cannot mix both url and custom_id with Button")
 
         if not isinstance(custom_id, str) and custom_id is not None:
-            raise TypeError(f"expected custom_id to be str, not {custom_id.__class__.__name__}")
+            raise TypeError(
+                f"expected custom_id to be str, not {custom_id.__class__.__name__}"
+            )
 
         self._provided_custom_id = custom_id is not None
         if url is None and custom_id is None:
@@ -119,7 +121,10 @@ class Button(Item[V]):
             elif isinstance(emoji, _EmojiTag):
                 emoji = emoji._to_partial()
             else:
-                raise TypeError(f"expected emoji to be str, Emoji, or PartialEmoji not {emoji.__class__}")
+                raise TypeError(
+                    "expected emoji to be str, Emoji, or PartialEmoji not"
+                    f" {emoji.__class__}"
+                )
 
         self._underlying = ButtonComponent._raw_construct(
             type=ComponentType.button,
@@ -134,7 +139,7 @@ class Button(Item[V]):
 
     @property
     def style(self) -> ButtonStyle:
-        """:class:`discord.ButtonStyle`: The style of the button."""
+        """The style of the button."""
         return self._underlying.style
 
     @style.setter
@@ -142,15 +147,15 @@ class Button(Item[V]):
         self._underlying.style = value
 
     @property
-    def custom_id(self) -> Optional[str]:
-        """Optional[:class:`str`]: The ID of the button that gets received during an interaction.
+    def custom_id(self) -> str | None:
+        """The ID of the button that gets received during an interaction.
 
         If this button is for a URL, it does not have a custom ID.
         """
         return self._underlying.custom_id
 
     @custom_id.setter
-    def custom_id(self, value: Optional[str]):
+    def custom_id(self, value: str | None):
         if value is not None and not isinstance(value, str):
             raise TypeError("custom_id must be None or str")
         if value and len(value) > 100:
@@ -158,19 +163,19 @@ class Button(Item[V]):
         self._underlying.custom_id = value
 
     @property
-    def url(self) -> Optional[str]:
-        """Optional[:class:`str`]: The URL this button sends you to."""
+    def url(self) -> str | None:
+        """The URL this button sends you to."""
         return self._underlying.url
 
     @url.setter
-    def url(self, value: Optional[str]):
+    def url(self, value: str | None):
         if value is not None and not isinstance(value, str):
             raise TypeError("url must be None or str")
         self._underlying.url = value
 
     @property
     def disabled(self) -> bool:
-        """:class:`bool`: Whether the button is disabled or not."""
+        """Whether the button is disabled or not."""
         return self._underlying.disabled
 
     @disabled.setter
@@ -178,23 +183,23 @@ class Button(Item[V]):
         self._underlying.disabled = bool(value)
 
     @property
-    def label(self) -> Optional[str]:
-        """Optional[:class:`str`]: The label of the button, if available."""
+    def label(self) -> str | None:
+        """The label of the button, if available."""
         return self._underlying.label
 
     @label.setter
-    def label(self, value: Optional[str]):
+    def label(self, value: str | None):
         if value and len(str(value)) > 80:
             raise ValueError("label must be 80 characters or fewer")
         self._underlying.label = str(value) if value is not None else value
 
     @property
-    def emoji(self) -> Optional[PartialEmoji]:
-        """Optional[:class:`.PartialEmoji`]: The emoji of the button, if available."""
+    def emoji(self) -> PartialEmoji | None:
+        """The emoji of the button, if available."""
         return self._underlying.emoji
 
     @emoji.setter
-    def emoji(self, value: Optional[Union[str, Emoji, PartialEmoji]]):  # type: ignore
+    def emoji(self, value: str | Emoji | PartialEmoji | None):  # type: ignore
         if value is None:
             self._underlying.emoji = None
         elif isinstance(value, str):
@@ -202,10 +207,13 @@ class Button(Item[V]):
         elif isinstance(value, _EmojiTag):
             self._underlying.emoji = value._to_partial()
         else:
-            raise TypeError(f"expected str, Emoji, or PartialEmoji, received {value.__class__} instead")
+            raise TypeError(
+                "expected str, Emoji, or PartialEmoji, received"
+                f" {value.__class__} instead"
+            )
 
     @classmethod
-    def from_component(cls: Type[B], button: ButtonComponent) -> B:
+    def from_component(cls: type[B], button: ButtonComponent) -> B:
         return cls(
             style=button.style,
             label=button.label,
@@ -237,12 +245,12 @@ class Button(Item[V]):
 
 def button(
     *,
-    label: Optional[str] = None,
-    custom_id: Optional[str] = None,
+    label: str | None = None,
+    custom_id: str | None = None,
     disabled: bool = False,
     style: ButtonStyle = ButtonStyle.secondary,
-    emoji: Optional[Union[str, Emoji, PartialEmoji]] = None,
-    row: Optional[int] = None,
+    emoji: str | Emoji | PartialEmoji | None = None,
+    row: int | None = None,
 ) -> Callable[[ItemCallbackType], ItemCallbackType]:
     """A decorator that attaches a button to a component.
 
@@ -259,7 +267,7 @@ def button(
         with it.
 
     Parameters
-    ------------
+    ----------
     label: Optional[:class:`str`]
         The label of the button, if any.
     custom_id: Optional[:class:`str`]
